RadonMetrics/CodeMetricsCalculator.py

changeset 13
22bc345844e7
parent 10
8b1920a22df3
child 37
7fd806094f0f
--- a/RadonMetrics/CodeMetricsCalculator.py	Sat Sep 19 11:54:33 2015 +0200
+++ b/RadonMetrics/CodeMetricsCalculator.py	Sat Sep 19 18:24:07 2015 +0200
@@ -3,10 +3,14 @@
 # Copyright (c) 2015 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
+"""
+Module implementing the raw code metrics service.
+"""
+
 from __future__ import unicode_literals
 
 try:
-    str = unicode       # __IGNORE_EXCEPTION __IGNORE_WARNING__
+    str = unicode       # __IGNORE_EXCEPTION__ __IGNORE_WARNING__
 except NameError:
     pass
 
@@ -38,7 +42,7 @@
     @param file source filename
     @type str
     @param text source text
-    @param str
+    @type str
     @return tuple containing the result dictionary
     @rtype (tuple of dict)
     """
@@ -49,7 +53,7 @@
     """
     Module function to calculate the raw code metrics for a batch of files.
     
-    @param argumentsList list of arguments tuples as given for check
+    @param argumentsList list of arguments tuples as given for rawCodeMetrics
     @type list
     @param send reference to send function
     @type function
@@ -97,7 +101,8 @@
 
 def worker(input, output):
     """
-    Module function acting as the parallel worker for the style check.
+    Module function acting as the parallel worker for the raw code metrics
+    calculation.
     
     @param input input queue
     @type multiprocessing.Queue

eric ide

mercurial